Module: Google::Cloud::DataCatalog

Defined in:
lib/google/cloud/data_catalog.rb,
lib/google/cloud/data_catalog/version.rb

Constant Summary collapse

VERSION =
"2.3.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.data_catalog| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-data_catalog library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



298
299
300
301
302
# File 'lib/google/cloud/data_catalog.rb', line 298

def self.configure
  yield ::Google::Cloud.configure.data_catalog if block_given?

  ::Google::Cloud.configure.data_catalog
end

.data_catalog(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DataCatalog.

By default, this returns an instance of Google::Cloud::DataCatalog::V1::DataCatalog::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DataCatalog service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DataCatalog service. You can determine whether the method will succeed by calling data_catalog_available?.

About DataCatalog

Deprecated: Please use Dataplex Catalog instead.

Data Catalog API service allows you to discover, understand, and manage your data.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/google/cloud/data_catalog.rb', line 78

def self.data_catalog version: :v1, transport: :grpc, &block
  require "google/cloud/data_catalog/#{version.to_s.downcase}"

  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::DataCatalog.const_get(package_name).const_get(:DataCatalog)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.data_catalog_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DataCatalog service is supported by the current client. If true, you can retrieve a client object by calling data_catalog. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DataCatalog service, or if the versioned client gem needs an update to support the DataCatalog service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/google/cloud/data_catalog.rb', line 102

def self.data_catalog_available? version: :v1, transport: :grpc
  require "google/cloud/data_catalog/#{version.to_s.downcase}"
  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::DataCatalog.const_get package_name
  return false unless service_module.const_defined? :DataCatalog
  service_module = service_module.const_get :DataCatalog
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.policy_tag_manager(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for PolicyTagManager.

By default, this returns an instance of Google::Cloud::DataCatalog::V1::PolicyTagManager::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PolicyTagManager service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PolicyTagManager service. You can determine whether the method will succeed by calling policy_tag_manager_available?.

About PolicyTagManager

Policy Tag Manager API service allows you to manage your policy tags and taxonomies.

Policy tags are used to tag BigQuery columns and apply additional access control policies. A taxonomy is a hierarchical grouping of policy tags that classify data along a common axis.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



153
154
155
156
157
158
159
160
161
162
163
# File 'lib/google/cloud/data_catalog.rb', line 153

def self.policy_tag_manager version: :v1, transport: :grpc, &block
  require "google/cloud/data_catalog/#{version.to_s.downcase}"

  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::DataCatalog.const_get(package_name).const_get(:PolicyTagManager)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.policy_tag_manager_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the PolicyTagManager service is supported by the current client. If true, you can retrieve a client object by calling policy_tag_manager. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PolicyTagManager service, or if the versioned client gem needs an update to support the PolicyTagManager service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/google/cloud/data_catalog.rb', line 177

def self.policy_tag_manager_available? version: :v1, transport: :grpc
  require "google/cloud/data_catalog/#{version.to_s.downcase}"
  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::DataCatalog.const_get package_name
  return false unless service_module.const_defined? :PolicyTagManager
  service_module = service_module.const_get :PolicyTagManager
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.policy_tag_manager_serialization(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for PolicyTagManagerSerialization.

By default, this returns an instance of Google::Cloud::DataCatalog::V1::PolicyTagManagerSerialization::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the PolicyTagManagerSerialization service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the PolicyTagManagerSerialization service. You can determine whether the method will succeed by calling policy_tag_manager_serialization_available?.

About PolicyTagManagerSerialization

Policy Tag Manager Serialization API service allows you to manipulate your policy tags and taxonomies in a serialized format.

Taxonomy is a hierarchical group of policy tags.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



226
227
228
229
230
231
232
233
234
235
236
# File 'lib/google/cloud/data_catalog.rb', line 226

def self.policy_tag_manager_serialization version: :v1, transport: :grpc, &block
  require "google/cloud/data_catalog/#{version.to_s.downcase}"

  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::DataCatalog.const_get(package_name).const_get(:PolicyTagManagerSerialization)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.policy_tag_manager_serialization_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the PolicyTagManagerSerialization service is supported by the current client. If true, you can retrieve a client object by calling policy_tag_manager_serialization. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the PolicyTagManagerSerialization service, or if the versioned client gem needs an update to support the PolicyTagManagerSerialization service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/google/cloud/data_catalog.rb', line 250

def self.policy_tag_manager_serialization_available? version: :v1, transport: :grpc
  require "google/cloud/data_catalog/#{version.to_s.downcase}"
  package_name = Google::Cloud::DataCatalog
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::DataCatalog.const_get package_name
  return false unless service_module.const_defined? :PolicyTagManagerSerialization
  service_module = service_module.const_get :PolicyTagManagerSerialization
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end